Skip to contents

Checks if `x` is a list with each element named.

Usage

is_fully_named_list(x)

Arguments

x

An object

Value

TRUE or FALSE.

Details

The empty list is a special case: is_fully_named_list(list()) returns FALSE, because a fully named list must have at least one element. The other three predicates in this family return TRUE for list().

Examples

is_fully_named_list(list())
#> [1] FALSE
is_fully_named_list(list(1))
#> [1] FALSE
is_fully_named_list(list("a"=1))
#> [1] TRUE
is_fully_named_list(list("a"=1, 2))
#> [1] FALSE